-----------------------------------------------------------------------------------------------
-- Client Lua Script for RestXPReminder
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"

local RestXPReminder = {}

local Loc = Apollo.GetPackage("Gemini:Locale-1.0").tPackage:GetLocale("RestXPReminder", true)


function RestXPReminder:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self
    return o
end

function RestXPReminder:Init()
    Apollo.RegisterAddon(self)
end

function RestXPReminder:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("RestXPReminder.xml")
	self.xmlDoc:RegisterCallback("OnDocumentReady", self)
end

function RestXPReminder:OnDocumentReady()
	Apollo.RegisterSlashCommand("camp", "OnCampSlashCommand", self)

	--Events don't work. Workaround by Timer.
	Apollo.RegisterEventHandler("GenericEvent_PlayerCampStart", "OnPlayerCamp", self)
	Apollo.RegisterEventHandler("GenericEvent_PlayerExitStart", "OnPlayerExit", self)
	Apollo.RegisterEventHandler("GenericEvent_PlayerExitCancel", "OnCancel", self)
    Apollo.RegisterTimerHandler("HalfSecTimer", "OnTimer", self)

	Apollo.CreateTimer("HalfSecTimer", 0.50, true)
    -- load our forms
    self.wndMain = Apollo.LoadForm(self.xmlDoc, "RestXPReminderForm", "TooltipStratum", self)
    self.wndMain:Show(false)
	self.xmlDoc = nil
end

function RestXPReminder:OnCampSlashCommand()
	self:OnPlayerCamp()
	Camp()
end

function RestXPReminder:OnTimer()
	if IsDemo() then
		ExitNow()
		return
	end
	local tExitInfo = GameLib.GetGameExitInfo()
	if tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.None then
		self.wndMain:Show(false)
		return end
		--[[if HousingLib.IsResidenceOwner() then
		Print("IsResidence")
		end
		if HousingLib.IsOnMyResidence() then
		Print("isonmy")
		end--]]
		--.."isonmy:"..HousingLib.IsOnMyResidence()
	local cooldown = GameLib.GetSpell(38408):GetCooldownRemaining()
	if not HousingLib.IsResidenceOwner() then
		self.wndMain:FindChild("Teleport"):SetText(Loc["You have no house."])
	elseif (cooldown and cooldown > 0) then
		if cooldown > 60 then
			self.wndMain:FindChild("Teleport"):SetText(Loc["Cooldown: "]..string.format("%d", cooldown/60).."m")
		else
			self.wndMain:FindChild("Teleport"):SetText(Loc["Cooldown: "]..string.format("%d", cooldown).."s")
		end
	else
		self.wndMain:FindChild("Teleport"):SetText(Loc["Teleport Home"])
	end
	if tExitInfo.ePendingEvent == GameLib.CodeEnumExitEvent.Quit then
		self.wndMain:FindChild("Title"):SetText(Apollo.GetString("CRB_Exit"))
		self.wndMain:FindChild("Message"):SetText(Apollo.GetString("GameExit_TimeTillQuit"))
		self.wndMain:FindChild("DropDown"):Show(true)
		
		--self.wndMain:FindChild("BG_Inset"):SetAnchorOffsets(20, -27, 180, 13)
		--self.wndMain:FindChild("Time"):SetAnchorOffsets(-145, -27, -29, 13)
	else
		self.wndMain:FindChild("Title"):SetText(Apollo.GetString("Options_SwitchCharacter"))
		self.wndMain:FindChild("Message"):SetText(Apollo.GetString("GameExit_TimeTillCamp"))
		self.wndMain:FindChild("DropDown"):Show(false)
		self.wndMain:FindChild("LeaveNowContainer"):Show(false)
		
	--	self.wndMain:FindChild("BG_Inset"):SetAnchorOffsets(107, -27, 267, 13)
	--	self.wndMain:FindChild("Time"):SetAnchorOffsets(-58, -27, 58, 13)
	end
	self.wndMain:Show(true)
	self.wndMain:FindChild("Time"):SetText(String_GetWeaselString(Apollo.GetString("GameExit_Timer"), tExitInfo.fTimeRemaining))

	-- TODO: Do this the right way when there's time
	local nSeconds = math.floor(tExitInfo.fTimeRemaining)
	local strOutput = nSeconds < 10 and Apollo.GetString("GameExit_ShortTimer") or Apollo.GetString("GameExit_NumTimer")
	self.wndMain:FindChild("Time"):SetText(String_GetWeaselString(strOutput, nSeconds))
end

function RestXPReminder:OnPlayerCamp()
	self.wndMain:Show(true)
	self.wndMain:FindChild("Title"):SetText(Apollo.GetString("Options_SwitchCharacter"))
	self.wndMain:FindChild("Message"):SetText(Apollo.GetString("GameExit_TimeTillCamp"))
end

function RestXPReminder:OnPlayerExit()
	self.wndMain:Show(true)
	self.wndMain:FindChild("Title"):SetText(Apollo.GetString("CRB_Exit"))
	self.wndMain:FindChild("Message"):SetText(Apollo.GetString("GameExit_TimeTillQuit"))
end

-----------------------------------------------------------------------------------------------
-- RestXPReminderForm Functions
-----------------------------------------------------------------------------------------------

function RestXPReminder:OnCancel()
	self.wndMain:Show(false)
	CancelExit()
end

function RestXPReminder:OnLeaveNow( wndHandler, wndControl, eMouseButton )
	ExitNow()
end

function RestXPReminder:OnDropDown( wndHandler, wndControl, eMouseButton )
	local bVisibility = self.wndMain:FindChild("LeaveNowContainer"):IsShown()
	self.wndMain:FindChild("LeaveNowContainer"):Show(not bVisibility)
end

local RestXPReminderInst = RestXPReminder:new()
RestXPReminderInst:Init()


